@@ -1,5 +1,29 @@
 svc <- paws::appstream()
 
+test_that("describe_app_blocks", {
+  expect_error(svc$describe_app_blocks(), NA)
+})
+
+test_that("describe_app_blocks", {
+  expect_error(svc$describe_app_blocks(MaxResults = 20), NA)
+})
+
+test_that("describe_application_fleet_associations", {
+  expect_error(svc$describe_application_fleet_associations(), NA)
+})
+
+test_that("describe_application_fleet_associations", {
+  expect_error(svc$describe_application_fleet_associations(MaxResults = 20), NA)
+})
+
+test_that("describe_applications", {
+  expect_error(svc$describe_applications(), NA)
+})
+
+test_that("describe_applications", {
+  expect_error(svc$describe_applications(MaxResults = 20), NA)
+})
+
 test_that("describe_directory_configs", {
   expect_error(svc$describe_directory_configs(), NA)
 })
